## 画角へのフィット対象となるメッシュの登録

![register_mesh](register_mesh.png)

自動生成されたカメラは、メッシュを対象に計算を行って自身の位置を計算します。その際にデフォルトでは、ビュー上に表示されている全メッシュが計算対象になります。

一部のメッシュだけを計算対象としたい場合、シーン内で予め登録を行う必要があります。

![diff_register](diff_register.png)

以下に登録方法を記述しますが、本ページ下部では、このツールに依らない登録方法も紹介しています。



### Mayaでの登録ツール起動
---
以下のコマンドで表示されるウィンドウを通して、メッシュの登録を行います。

```python
import hardware_render_animations
hardware_render_animations.register_tool()
```
![register_maya_window](register_maya_window.png)



### 登録方法

---
シーンを開き、以下を行います。

1. 登録するオブジェクトを選択します
2. 「Add Mark」を押します
3. 「marked_by_hardware_render_animations」というプロパティが追加されたことを確認します。
4. シーンを保存します

:information_source: ​Blenderの場合はオブジェクトのプロパティとして、Mayaの場合はシェイプノードのアトリビュートとして追加されます。

![add](add.png)

![maya_attr](maya_attr.png)

「marked_by_hardware_render_animations」というプロパティを持つオブジェクトのみが、カメラの位置計算に関係するようになります。

プロパティの値は意味を持ちません。



### 登録の解除

---

開いたシーンで、以下を行います。

1. 解除するオブジェクトを選択します
2. 「Remove Mark」を押します
3. 「marked_by_hardware_render_animations」が消えたことを確認します。
4. シーンを保存します。



### 登録メッシュの確認

---

「Select Marked Meshes」を押すと、カメラの位置計算に関係するオブジェクトが選択状態になります。



### レンダリング時の設定

---

以上の設定は、[レンダリング時のメッシュ設定](../gui_main/capture_settings/capture_settings.html)で「PreregisteredMeshes」を選択すると反映されます。

![preregisterd_in_gui](preregisterd_in_gui.png)



### 本ツールに依らない登録メッシュの設定方法

----

リグのメッシュなど、カメラの計算対象に含みたくないものが一定の法則を持つ場合、本ツールを使用せずにメッシュの登録が可能です。



本ツールでは、ノードに対して特定名称のアトリビュートを付与しているに過ぎません。

そのため、スクリプトで

「**marked_by_hardware_render_animations**」

という名称のアトリビュートを付与することで、計算対象が付与済みのものに限定されます。

* Mayaでは、シェイプノードに対して付与してください
* Blenderでは、オブジェクトに対して付与してください（メッシュではありません）

両ツールとも、アトリビュートの型は問いません。



下記のコードを参照してください。

```
ATTR_NAME = 'marked_by_hardware_render_animations'

# Maya
cmds.addAttr('pCubeShape1', at='bool', dv=1, ln=ATTR_NAME)

# Blender
OBJ = bpy.context.scene.objects['Cube']
OBJ[ATTR_NAME] = 1
```



------

[戻る: index](../index.html)