# -*-coding:utf-8-*-
u"""独立プロセスでGUIを起動.

blenderなど、PySide2の組み込みがないDCCツールから呼ばれる。

DCCツール側からsubprocessで、PySide2へのパスを持つPythonを起動。
その起動引数に本モジュールのパスを指定させる。

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110- 1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

Author: Masayuki Osaka
"""
from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function
import os
import sys
import inspect
import argparse
try:
    from PySide2 import QtWidgets
except ImportError:
    raise Exception(
        'Failed to import PySide2.\n' +
        'Confirm the setting in user_setting.txt.'
    )


if __name__ != '__main__':
    # このモジュールはトップレベルでのみ使用可能
    raise Exception('This module must be called as main.')


# このモジュールを起動させたDCCツールのexecutableを取得
PARSER = argparse.ArgumentParser()
PARSER.add_argument(
    '--dcc', type=str, nargs=1, help='Executable path of DCC tool.'
)
ARGS = PARSER.parse_args()


def set_this_package_to_python_path():
    u"""このパッケージをDCCツールに認識させる."""
    # このパッケージのある場所
    package_root = os.path.normpath(
        os.path.join(inspect.stack()[0][1], '../../')
    ).replace(os.sep, '/')
    if package_root not in sys.path:
        sys.path.append(package_root)


set_this_package_to_python_path()
# gui起動
app = QtWidgets.QApplication(sys.argv)
try:
    import hardware_render_animations
    from hardware_render_animations.modules.setting import Setting
    # 呼び出したDCCツールの起動パスをレンダー実行で使用するために記録
    Setting.caller_dcc_path = ARGS.dcc[0]
    # レンダー実行
    gui = hardware_render_animations.main()
except Exception:
    import traceback
    err = traceback.format_exc()
    sys.stdout.write(err)
    sys.exit(err)
sys.exit(app.exec_())
