# -*-coding:utf-8-*-
u"""開いているMayaシーンからハードウェアレンダーを行うために必要な情報を集める.

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110- 1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

Author: Masayuki Osaka
"""
from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function

import maya.cmds as cmds
import maya.api.OpenMayaAnim as om2a

from ..setting import Setting
from . import confirm_setting_abstract as setabc


class ConfirmSetting(setabc.AbstractConfirmSetting):
    u"""シーンの情報をsettings.Settingへ伝えるための抽象クラス."""

    def set_resolution_by_current_scene(self):
        u"""レンダー解像度をsetting.Settingへ伝える."""
        render = 'defaultResolution'
        Setting.resolution_x = cmds.getAttr('{}.width'.format(render))
        Setting.resolution_y = cmds.getAttr('{}.height'.format(render))

    def set_animation_range_by_current_scene(self):
        u"""レンダーフレームの始、終をsetting.Settingへ伝える."""
        Setting.start_frame = int(om2a.MAnimControl.minTime().value)
        Setting.end_frame = int(om2a.MAnimControl.maxTime().value)

    def set_fps_by_current_scene(self):
        u"""fpsをsetting.Settingへ伝える."""
        fps_str = cmds.currentUnit(q=1, t=1)
        fps_digit = dict(
            game=15, film=24, pal=25, ntsc=30, show=48, palf=50, ntscf=60
        )
        if fps_str not in fps_digit:
            raise Exception(
                'This tool do not support currentUnit: {}'.format(fps_str)
            )
        Setting.fps = fps_digit[fps_str]

    def set_coordinate_by_current_scene(self):
        u"""DCCのアップ軸、水平軸をsetting.Settingへ伝える."""
        Setting.coord_up_id = 1
        Setting.coord_gnd_id = 2
