# -*-coding:utf-8-*-
u"""エラーを表示させるためのログ.

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110- 1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

Author: Masayuki Osaka
"""
from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function
import traceback
import getpass
import os

from .setting import Setting


class ErrorLog(object):
    u"""エラーを表示させるためのログ."""

    @staticmethod
    def initialize():
        u"""空のログファイルを作成."""
        with open(Setting.LOG_PATH, 'w') as fobj:
            fobj.write('')

    @staticmethod
    def add_error(scene_path=''):
        u"""異常を追記する.

        scene_path: 異常が発生したシーンパス
        """
        if scene_path:
            with open(Setting.LOG_PATH, 'a') as fobj:
                fobj.write('scene: ' + scene_path)

        with open(Setting.LOG_PATH, 'a') as fobj:
            msg = traceback.format_exc()
            fobj.write(
                msg.replace(getpass.getuser(), '<username>') +
                '\n'
            )

    @staticmethod
    def get_error_messages():
        u"""保存していたエラーメッセージを返して、ログファイルは除去.

        return: unicode
        """
        with open(Setting.LOG_PATH) as fobj:
            text = fobj.read()
        return text

    @staticmethod
    def delete():
        u"""ログファイル除去."""
        os.remove(Setting.LOG_PATH)
