# -*-coding:utf-8-*-
u"""guiのトップ.

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110- 1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

Author: Masayuki Osaka
"""
from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function

from maya.app.general.mayaMixin import MayaQWidgetBaseMixin
import maya.cmds as cmds

from . import gui_abstract as guiabc


class RenderFormatCombobox(guiabc.AbstractRenderFormatComboBox):
    u"""保存時のフォーマットを決めるcombobox.

    自身と、関連Widgetの表示内容を変える
    """

    class Avi(guiabc.AbstractRenderFormatComboBox.AbstractFormat):
        u"""avi."""

        sub_labels = ('IYUV', 'MS-CRAM', 'none')

    class Png(guiabc.AbstractRenderFormatComboBox.AbstractFormat):
        u"""png."""

        display_encode = display_quality = False
        sub_labels = ('png',)  # Mayaでは必要


class Gui(MayaQWidgetBaseMixin, guiabc.AbstractGui):
    u"""gui."""

    def __init__(self, parent=None):
        u"""gui."""
        super(Gui, self).__init__(parent)

    def _make_render_format_combobox(self):
        u"""拡張子と関連要素のGUI表示を設定するcomboboxの作成.

        return: QComboBox()
        """
        return RenderFormatCombobox(self.cmb_encode, self.frame_quality)

    def _dcc_own_gui_setup(self):
        u"""DCCツール毎に独自なGUI編集."""
        pass  # 特になし

    def _delete_old_gui(self):
        u"""既存のUI削除."""
        if cmds.window(self.WINDOW_NAME, ex=1):
            cmds.deleteUI(self.WINDOW_NAME)

    def _camera_default_rotation(self):
        u"""カメラの初期値.

        return: tuple(float, float, float)
        """
        return (0.0, 45.0, 0.0)

    def _camera_default_clippingplane(self):
        u"""カメラの初期クリッピングプレーン.

        return: tuple(float, float)
        """
        return (0.1, 10000.0)
