# -*-coding:utf-8-*-
u"""レンダリング対象メッシュ登録用GUIを起動.

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110- 1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

Author: Masayuki Osaka
"""
import os
import inspect

from PySide2.QtWidgets import QMainWindow, QWidget

from ..setting import Setting
from .resources import widget_register as wr


class RegisterWidget(QWidget, wr.Ui_Form):
    u"""レンダリング対象メッシュ登録用Widget."""

    def __init__(self, parent=None):
        u"""constructor."""
        super(RegisterWidget, self).__init__(parent)
        self.setupUi(self)


class AbstractRegisterGui(QMainWindow):
    u"""レンダリング対象メッシュ登録用GUI起動."""

    WINDOW_NAME = 'register_window_hardware_render_animations'
    CURRENTDIR = os.path.dirname(inspect.stack()[0][1].replace(os.sep, '/'))
    WIDGETPATH = '{}/resources/widget_register.ui'.format(CURRENTDIR)

    ATTR_NAME = Setting.REGISTERD_MARK

    def __init__(self, parent=None):
        u"""constructor."""
        super(AbstractRegisterGui, self).__init__(parent)
        self._delete_old_gui()
        self.setObjectName(self.WINDOW_NAME)
        self.setWindowTitle('Register Widget')

        widget = RegisterWidget()
        self.setCentralWidget(widget)

        widget.label.setText('{}\nSubtool'.format(Setting.PACKAGE_NAME))

        widget.bt_add.clicked.connect(self._add_mark)
        widget.bt_remove.clicked.connect(self._remove_mark)
        widget.bt_select.clicked.connect(self._select_marked_meshes)

    def _delete_old_gui(self):
        u"""既存のUI削除."""
        raise NotImplementedError

    def _add_mark(self):
        u"""フォーカスの対象を限定するためのプロパティを付与."""
        raise NotImplementedError

    def _remove_mark(self):
        u"""フォーカスの対象を限定するためのプロパティを削除."""
        raise NotImplementedError

    def _select_marked_meshes(self):
        u"""フォーカス対象を限定するマークがあり、値がTrueのメッシュを選択状態にする."""
        raise NotImplementedError
