# -*-coding:utf-8-*-
u"""レンダリング対象メッシュ登録用GUIを起動.

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110- 1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

Author: Masayuki Osaka
"""
from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function

from maya.app.general.mayaMixin import MayaQWidgetBaseMixin
import maya.cmds as cmds

from . import gui_register_abstract as gregabc


class RegisterGui(MayaQWidgetBaseMixin, gregabc.AbstractRegisterGui):
    u"""レンダリング対象メッシュ登録用GUI起動."""

    def _delete_old_gui(self):
        u"""既存のUI削除."""
        print(self.WINDOW_NAME)
        if cmds.window(self.WINDOW_NAME, ex=1):
            cmds.deleteUI(self.WINDOW_NAME)

    def _add_mark(self):
        u"""フォーカスの対象を限定するためのプロパティを付与."""
        meshes = cmds.ls(sl=1, dag=1, type='mesh')
        meshes = cmds.ls(meshes, ni=1)
        for mesh in meshes:
            if not cmds.attributeQuery(self.ATTR_NAME, n=mesh, ex=1):
                cmds.addAttr(mesh, at='bool', dv=1, ln=self.ATTR_NAME)

    def _remove_mark(self):
        u"""フォーカスの対象を限定するためのプロパティを削除."""
        meshes = cmds.ls(sl=1, dag=1, type='mesh')
        meshes = cmds.ls(meshes, ni=1)
        for mesh in meshes:
            if cmds.attributeQuery(self.ATTR_NAME, n=mesh, ex=1):
                try:
                    cmds.setAttr('{}.{}'.format(mesh, self.ATTR_NAME), lock=0)
                except RuntimeError:
                    pass  # リファレンス先での追加アトリは、削除可かつアンロック不可
                cmds.deleteAttr('{}.{}'.format(mesh, self.ATTR_NAME))

    def _select_marked_meshes(self):
        u"""フォーカス対象を限定するマークがあり、値がTrueのメッシュを選択状態にする."""
        meshes = cmds.ls(dag=1, type='mesh')
        meshes = [
            x for x in meshes if cmds.attributeQuery(self.ATTR_NAME, n=x, ex=1)
        ]
        cmds.select(cmds.listRelatives(meshes, parent=1), r=1)
