# -*-coding:utf-8-*-
u"""各メッシュ毎の頂点座標を、DCCツールに沿った形で取得.

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110- 1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

Author: Masayuki Osaka
"""
from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function

from ..setting import Setting


class AbstractMesh(object):
    u"""頂点を取得しやすくするための、各メッシュの抽象クラス."""

    def __init__(self, mesh_object):
        u"""construcor.

        mesh_object: 各DCCタイプのメッシュオブジェクト
        """
        raise NotImplementedError

    def _hidden_in_view(self):
        u"""非表示であるかを返す."""
        raise NotImplementedError

    def _current_points(self):
        u"""現フレームでの頂点座標リストを取得."""
        raise NotImplementedError

    def get_current_points(self):
        u"""頂点座標のリストを返す.

        非表示かつ、非表示をカウントしないモードの場合は[]を返す
        """
        if Setting.count_hide_vertices:
            return self._current_points()
        if self._hidden_in_view():
            return []
        return self._current_points()


class AbstractPointContaier(object):
    u"""全メッシュの点群を管理する."""

    def __init__(self):
        u"""constructor."""
        self.clear()
        self._center_position = None
        self._heights = None

    def clear(self):
        u"""DCCツールのapiに沿った点群格納オブジェクトを初期化."""
        self.points = None
        self._center_position = None
        self._heights = None

    def set_meshes(self, mesh_objects):
        u"""AbstractMeshを継承したクラスのインスタンスリストを作成する."""
        self.meshes = [AbstractMesh(x) for x in mesh_objects]

    def get_current_points(self):
        u"""全メッシュの頂点を取得.

        return: DCCツールのapiに沿ったポイントリスト
        """
        raise NotImplementedError

    def append_current_points(self):
        u"""self.pointsへ全メッシュの頂点を蓄積させる."""
        self.points += self.get_current_points()
