# -*-coding:utf-8-*-
u"""使いまわせる、シンプルなパス加工.

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110- 1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

Author: Masayuki Osaka
"""
from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function
import os
import subprocess

from .setting import Setting


class Pathes(object):
    u"""使いまわせる、シンプルなパスの加工."""

    @staticmethod
    def expand_pathes(*args):
        u"""DCCツールの処理対象になる、実在するファイルリストを作成する.

        args: ファイルまたはフォルダパス
        return: list[unicode,] DCCツールに対応したファイルのリスト
        """
        exts = Setting.scene_exts()
        files = [x for x in args if
                 os.path.isfile(x) and any(x.endswith(y) for y in exts)]
        directories = [x for x in args if os.path.isdir(x)]

        def walk(directory):
            u"""DCCツールに対応したファイルリストのジェネレータ."""
            for dirname, _, items in os.walk(directory):
                dirname = dirname.replace(os.sep, '/')
                for item in items:
                    if any(item.endswith(x) for x in exts):
                        yield '{}/{}'.format(dirname, item)

        for directory in directories:
            files += [x for x in walk(directory)]
        return sorted(set(files))

    @staticmethod
    def open_logfolder():
        u"""ログファイル用フォルダを開く.

        return: bool: 実行に成功したか
        """
        if not os.path.isdir(Setting.LOG_FOLDER_PATH):
            return False
        subprocess.Popen('call {}'.format(Setting.LOG_FOLDER_PATH), shell=True)
        return True
