# -*-coding:utf-8-*-
u"""各DCCののVectorに関するapiの違いを吸収する.

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110- 1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

Author: Masayuki Osaka
"""
from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function
import numbers


class AbstractVector3D(object):
    u"""各DCCの違いに関わらずVector演算をし易くするため抽象クラス.

    各メソッドの引数, 辺数は基本的にVector3D型
    """

    def __init__(self, vector_object):
        u"""construcor.

        mesh_object: 各DCCタイプのVector3Dに関するオブジェクト
        """
        self._vec = vector_object

    @property
    def delegate(self):
        u"""各DCCの仕様に沿ったVectorのオブジェクトを返す."""
        return self._vec

    @property
    def x(self):
        u"""self._vecのx要素のgetter."""
        return self._vec.x

    @x.setter
    def x(self, v):
        u"""self._vecのx要素のsetter."""
        self._vec.x = v

    @property
    def y(self):
        u"""self._vecのy要素のgetter."""
        return self._vec.y

    @y.setter
    def y(self, v):
        u"""self._vecのy要素のsetter."""
        self._vec.y = v

    @property
    def z(self):
        u"""self._vecのz要素のgetter."""
        return self._vec.z

    @z.setter
    def z(self, v):
        u"""self._vecのz要素のsetter."""
        self._vec.z = v

    def normalize(self):
        u"""デリゲート."""
        return self.__class__(self._vec.normalize())

    def __add__(self, v):
        u"""デリゲート."""
        return self.__class__(self._vec.__add__(v._vec))

    def __mul__(self, v):
        u"""内積またはスカラー積."""
        if isinstance(v, numbers.Number):
            return self.__class__(self._vec.__mul__(v))
        return self._vec.__mul__(v._vec)

    def __sub__(self, v):
        u"""デリゲート."""
        return self.__class__(self._vec.__sub__(v._vec))

    def __div__(self, v):
        u"""デリゲート."""
        return self.__class__(self._vec.__div__(v))

    def __eq__(self, v):
        u"""デリゲート."""
        return self._vec.__eq__(v._vec)

    def __iadd__(self, v):
        u"""デリゲート."""
        return self.__class__(self._vec.__iadd__(v._vec))

    def __isub__(self, v):
        u"""デリゲート."""
        return self.__class__(self._vec.__isub__(v._vec))

    def __ne__(self, v):
        u"""デリゲート."""
        return self._vec.__ne__(v._vec)

    def __neg__(self):
        u"""デリゲート."""
        return self.__class__(self._vec.__neg__())

    def __repr__(self):
        u"""デリゲート."""
        return self._vec.__repr__()

    def __rmul__(self, v):
        u"""内積またはスカラー積."""
        if isinstance(v, numbers.Number):
            return self.__class__(self._vec.__mul__(v))
        return self._vec.__mul__(v._vec)

    def __str__(self):
        u"""デリゲート."""
        return self._vec.__str__()

    def __xor__(self, v):
        u"""外積."""
        return self.__class__(self._vec.__xor__(v._vec))

    def __getitem__(self, i):
        u"""getitem."""
        return self._vec[i]
