# -*-coding:utf-8-*-
u"""numpyでのVectorをDCCツール共通のクラス名で管理させる.

# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110- 1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

Author: Masayuki Osaka
"""
from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function
import numbers

import mathutils as mu

from . import vector_abstract as vecabs


class Vector3D(vecabs.AbstractVector3D):
    u"""演算を簡単にするために、numpy.arrayをDCCツール共通のクラス名で管理.

    各メソッドの引数, 辺数は基本的にVector3D型
    """

    def __init__(self, vector_object):
        u"""construcor.

        vector_objects:
        tuple or list (x, y, z)
        mathutils.Vector()
        """
        if isinstance(vector_object, mu.Vector):
            self._vec = vector_object
        else:
            self._vec = mu.Vector(vector_object)

    @property
    def x(self):
        u"""self._vecのx要素のgetter."""
        return self._vec.x

    @x.setter
    def x(self, v):
        u"""self._vecのx要素のsetter."""
        self._vec.x = v

    @property
    def y(self):
        u"""self._vecのy要素のgetter."""
        return self._vec.y

    @y.setter
    def y(self, v):
        u"""self._vecのy要素のsetter."""
        self._vec.y = v

    @property
    def z(self):
        u"""self._vecのz要素のgetter."""
        return self._vec.z

    @z.setter
    def z(self, v):
        u"""self._vecのz要素のsetter."""
        self._vec.z = v

    def normalize(self):
        u"""デリゲート."""
        return self.__class__(self._vec.normalized())

    def __mul__(self, v):
        u"""内積またはスカラー積."""
        if isinstance(v, numbers.Number):
                return self.__class__(self._vec.__mul__(v))
        return self._vec.dot(v._vec)

    def __eq__(self, v):
        u"""デリゲート."""
        return all(self._vec[i] == v._vec[i] for i in range(3))

    def __ne__(self, v):
        u"""デリゲート."""
        return any(self._vec[i] != v._vec[i] for i in range(3))

    def __rmul__(self, v):
        u"""内積またはスカラー積."""
        if isinstance(v, numbers.Number):
            return self.__class__(self._vec.__mul__(v))
        return self._vec.dot(v._vec)

    def __xor__(self, v):
        u"""外積."""
        return self.__class__(self._vec.cross(v._vec))
